pub struct BoolAdapter<Block, T> { /* private fields */ }Expand description
Adapts a sequence of bools (e.g., &[bool]) to emulate a bit
vector.
In particular, this adapter implements Bits, BitsMut, and
BitsPush as appropriate. It implement PartialEq<T> for all
T: Bits<Block=Block>. It does not, however, implement slicing, so
slice before you adapt.
Note that a bare Vec<bool> or &[bool] already implements Bits,
etc., with a Block type of u8. This means that it is only
compatible with other u8-based bit vectors. BoolAdapter is instead
parametrized by the block type, so it works with bit vectors, slices,
and adapters of any uniform block type.
Implementations
Sourceimpl<Block: BlockType, T> BoolAdapter<Block, T>
impl<Block: BlockType, T> BoolAdapter<Block, T>
Sourcepub fn new(bits: T) -> Self
pub fn new(bits: T) -> Self
Creates a new BoolAdapter from an underlying sequence of bools.
Note that the BoolAdapter derefs to the underlying bool sequence.
Examples
use nostd_bv::BitSliceable;
use nostd_bv::adapter::BoolAdapter;
let array = [0b101usize];
let bv1 = BoolAdapter::new(vec![true, false, true]);
let bv2 = array.bit_slice(0..3);
assert_eq!( bv1, bv2 );Sourcepub fn into_inner(self) -> T
pub fn into_inner(self) -> T
Gets the underlying bool sequence object back out of a BoolAdapter.